@@ -2,6 +2,8 @@ from typing import Any, Tuple, Union
 
 from ec2instances.ec2_instance_mapping import Ec2RemoteShellMapping
 
+from pyclvm._common.session import get_session
+
 
 def shell(
     instance_name: str, *commands: str, **kwargs: str
@@ -20,5 +22,5 @@ def shell(
         standard output, standard err if wait=True (default), otherwise ssm_client, command_id, instance_id
 
     """
-    instance = Ec2RemoteShellMapping(**kwargs)[instance_name]
+    instance = Ec2RemoteShellMapping(get_session(kwargs))[instance_name]
     return instance.execute(*commands)
